---
name: Bug report
about: Create a report to help us improve
title: 'Description of the bug'
labels: bug
assignees: ''

---

<!--- Provide a general summary of the issue in the title above -->

## Expected Behavior
<!--- Tell us what should happen. Add an example with all
 the information needed to reproduce the bug (descriptors, inputs, etc) -->

## Current Behavior
<!--- Tell us what happens instead of the expected behavior. Add an example with all
 the information needed to reproduce the bug (descriptors, inputs, etc) -->

## Environment (optional)
<!--- Information about the execution environment, in particular: Python version, Docker/Singularity version
 if relevant -->

## Context (optional)
<!--- How has this issue affected you? What are you trying to accomplish? -->
<!--- Providing context helps us come up with a solution that is most useful in the real world -->

## Possible fix (optional)
<!--- Not obligatory, but suggest an idea to fix the prroblem -->

## Related issues (optional)
<!--- Link any related issue -->
